/*
 * Copyright 2018 Google LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package com.google.cloud.tools.jib.api;

import com.google.cloud.tools.jib.configuration.ImageConfiguration;
import com.google.cloud.tools.jib.image.ImageReference;
import com.google.cloud.tools.jib.image.InvalidImageReferenceException;
import java.nio.file.Paths;
import org.junit.Assert;
import org.junit.Test;

/** Tests for {@link TarImage}. */
public class TarImageTest {

  @Test
  public void testToImageConfiguration() throws InvalidImageReferenceException {
    TarImage tarImage = TarImage.named("tar/image").saveTo(Paths.get("output/file"));
    ImageConfiguration imageConfiguration = tarImage.toImageConfiguration();

    Assert.assertEquals(
        ImageReference.parse("tar/image").toString(), imageConfiguration.getImage().toString());
    Assert.assertEquals(0, imageConfiguration.getCredentialRetrievers().size());
    Assert.assertEquals(Paths.get("output/file"), tarImage.getOutputFile());
  }
}
